import os
import numpy as np
import configparser

# Initialize configuration readers
config = configparser.ConfigParser()
params = configparser.ConfigParser()

# Load configurations from config.ini and params.ini
config.read('config.ini')
params.read('params.ini')

# Access paths from config.ini
CONFIGS_FOLDER = config['Paths']['CONFIGS_FOLDER']

# Define parameter ranges using params.ini or default values if None
def get_range_or_default(param_name):
    range_value = params['Params'].get(param_name, "None").split('#')[0].strip()
    
    if range_value == "None":
        default_param_name = param_name.replace('_range', '')
        return [float(params['Defaults'][default_param_name])] if default_param_name in params['Defaults'] else []
    start, stop, steps = map(str.strip, range_value.split(','))
    return np.linspace(float(start), float(stop), int(steps))

# Retrieve parameter ranges or default values
a0_values = get_range_or_default('a0_range')
a_values = get_range_or_default('a_range')
k_values = get_range_or_default('k_range')
L_values = get_range_or_default('L_range')
s_values = get_range_or_default('s_range')
n_values = get_range_or_default('n_range')
q_values = get_range_or_default('q_range')

# Load the base config template from base_template.txt
with open('base_template.txt', 'r') as file:
    base_config_content = file.read()

# Function to generate config content with updated parameters
def generate_config_content(a0, a, k, L, s, n, q):
    return base_config_content.format(a0=a0, a=a, k=k, L=L, s=s, n=n, q=q)

# Main script to generate config files with different parameter combinations
def generate_configs(output_directory):
    if not os.path.exists(output_directory):
        os.makedirs(output_directory)

    for a0 in a0_values:
        for a in a_values:
            for k in k_values:
                for L in L_values:
                    for s in s_values:
                        for n in n_values:
                            for q in q_values:
                                config_content = generate_config_content(a0, a, k, L, s, n, q)
                                filename = f"a0-{a0:.1f}_a-{a:.1f}_k-{k:.1f}_L-{L:.1f}_s-{s:.1f}_q-{q:.3f}_n-{n:.1f}.cfg"
                                filepath = os.path.join(output_directory, filename)

                                with open(filepath, 'w') as config_file:
                                    config_file.write(config_content)
                                print(f"Created: {filename}")

if __name__ == "__main__":
    generate_configs(CONFIGS_FOLDER)
